test Package
============

:mod:`test` Package
-------------------

.. automodule:: stoqlib.test
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tests_runner` Module
--------------------------

.. automodule:: stoqlib.test.tests_runner
    :members:
    :undoc-members:
    :show-inheritance:
